@@ -1,18 +1,14 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 import hashlib
 import logging
 import os
-
-from six.moves import cPickle as pickle
+import pickle
 
 from pelican.utils import mkdir_p
 
 logger = logging.getLogger(__name__)
 
 
-class FileDataCacher(object):
+class FileDataCacher:
     """Class that can cache data contained in files"""
 
     def __init__(self, settings, cache_name, caching_policy, load_policy):
@@ -35,7 +31,7 @@ class FileDataCacher(object):
             try:
                 with self._cache_open(self._cache_path, 'rb') as fhandle:
                     self._cache = pickle.load(fhandle)
-            except (IOError, OSError) as err:
+            except (OSError, UnicodeDecodeError) as err:
                 logger.debug('Cannot load cache %s (this is normal on first '
                              'run). Proceeding with empty cache.\n%s',
                              self._cache_path, err)
@@ -69,7 +65,7 @@ class FileDataCacher(object):
                 mkdir_p(self.settings['CACHE_PATH'])
                 with self._cache_open(self._cache_path, 'wb') as fhandle:
                     pickle.dump(self._cache, fhandle)
-            except (IOError, OSError, pickle.PicklingError) as err:
+            except (OSError, pickle.PicklingError) as err:
                 logger.warning('Could not save cache %s\n ... %s',
                                self._cache_path, err)
 
@@ -82,9 +78,7 @@ class FileStampDataCacher(FileDataCacher):
         and base path for filestamping operations
         """
 
-        super(FileStampDataCacher, self).__init__(settings, cache_name,
-                                                  caching_policy,
-                                                  load_policy)
+        super().__init__(settings, cache_name, caching_policy, load_policy)
 
         method = self.settings['CHECK_MODIFIED_METHOD']
         if method == 'mtime':
@@ -106,7 +100,7 @@ class FileStampDataCacher(FileDataCacher):
     def cache_data(self, filename, data):
         """Cache stamp and data for the given file"""
         stamp = self._get_file_stamp(filename)
-        super(FileStampDataCacher, self).cache_data(filename, (stamp, data))
+        super().cache_data(filename, (stamp, data))
 
     def _get_file_stamp(self, filename):
         """Check if the given file has been modified
@@ -120,7 +114,7 @@ class FileStampDataCacher(FileDataCacher):
 
         try:
             return self._filestamp_func(filename)
-        except (IOError, OSError, TypeError) as err:
+        except (OSError, TypeError) as err:
             logger.warning('Cannot get modification stamp for %s\n\t%s',
                            filename, err)
             return ''
@@ -134,8 +128,7 @@ class FileStampDataCacher(FileDataCacher):
         and current file stamp.
         """
 
-        stamp, data = super(FileStampDataCacher, self).get_cached_data(
-            filename, (None, default))
+        stamp, data = super().get_cached_data(filename, (None, default))
         if stamp != self._get_file_stamp(filename):
             return default
         return data
